# archiveswurm

Yet another client / implementation of the ArchivesSpace API in Python.

## What's here?

Just the parts I've needed for my own projects.  It's not comprehensive (yet).

## Why?

Because I find all the others difficult for implementing in my own projects.